@@ -10,7 +10,7 @@
 
 using namespace KUnifiedPush;
 
-AbstractPushProvider::AbstractPushProvider(const char *providerId, QObject *parent)
+AbstractPushProvider::AbstractPushProvider(QLatin1StringView providerId, QObject *parent)
     : QObject(parent)
     , m_providerId(providerId)
 {
@@ -18,11 +18,41 @@ AbstractPushProvider::AbstractPushProvider(const char *providerId, QObject *pare
 
 AbstractPushProvider::~AbstractPushProvider() = default;
 
-const char* AbstractPushProvider::providerId() const
+void AbstractPushProvider::resetSettings([[maybe_unused]] QSettings &settings)
+{
+}
+
+void AbstractPushProvider::acknowledgeMessage(const Client &client, const QString &messageIdentifier)
+{
+    Q_EMIT messageAcknowledged(client, messageIdentifier);
+}
+
+void AbstractPushProvider::changeUrgency(Urgency urgency)
+{
+    if (m_currentUrgency == urgency) {
+        Q_EMIT urgencyChanged();
+        return;
+    }
+
+    doChangeUrgency(urgency);
+}
+
+void AbstractPushProvider::doChangeUrgency(Urgency urgency)
+{
+    m_currentUrgency = urgency;
+    Q_EMIT urgencyChanged();
+}
+
+QLatin1StringView AbstractPushProvider::providerId() const
 {
     return m_providerId;
 }
 
+Urgency AbstractPushProvider::urgency() const
+{
+    return m_currentUrgency;
+}
+
 QNetworkAccessManager* AbstractPushProvider::nam()
 {
     if (!m_nam) {
